DioCall class

author:Vans Z date: 2019/1/13 0013

Constructors

DioCall(DioRequest request)

Properties

hashCode int
The hash code for this object.
no setterinherited
request DioRequest
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute() Future<Response>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited