PayPlugin class

author:Vans Z date: 2019-09-16

Constructors

PayPlugin()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deliverResult() Future<PayResult>
接受 super pay 的支付结果
isAppInstalled(String? packageName) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startActivityForResult(Map<String, dynamic> params) Future<bool>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

onPayFailed → const String
onPaySuccess → const String